svn commit: r1902137 - in /geronimo/specs/trunk/geronimo-mail_2.1_spec/src/main: java/jakarta/mail/internet/MimeUtility.java resources/META-INF/jakartamail.charset.map resources/META-INF/javamail.charset.map

[email protected] Tue, 21 Jun 2022 12:36:32 -0000
Newsgroups gmane.comp.java.geronimo.cvs
Message-ID <[email protected]>
Author: jlmonteiro
Date: Tue Jun 21 12:36:31 2022
New Revision: 1902137

URL: http://svn.apache.org/viewvc?rev=1902137&view=rev
Log:
Bad renaming - spec still uses javamail prefix

Added:
    geronimo/specs/trunk/geronimo-mail_2.1_spec/src/main/resources/META-INF/javamail.charset.map
Removed:
    geronimo/specs/trunk/geronimo-mail_2.1_spec/src/main/resources/META-INF/jakartamail.charset.map
Modified:
    geronimo/specs/trunk/geronimo-mail_2.1_spec/src/main/java/jakarta/mail/internet/MimeUtility.java

Modified: geronimo/specs/trunk/geronimo-mail_2.1_spec/src/main/java/jakarta/mail/internet/MimeUtility.java
URL: http://svn.apache.org/viewvc/geronimo/specs/trunk/geronimo-mail_2.1_spec/src/main/java/jakarta/mail/internet/MimeUtility.java?rev=1902137&r1=1902136&r2=1902137&view=diff
==============================================================================
--- geronimo/specs/trunk/geronimo-mail_2.1_spec/src/main/resources/META-INF/javamail.charset.map (added)
+++ geronimo/specs/trunk/geronimo-mail_2.1_spec/src/main/resources/META-INF/javamail.charset.map Tue Jun 21 12:36:31 2022
@@ -0,0 +1,87 @@
+##
+## Licensed to the Apache Software Foundation (ASF) under one
+## or more contributor license agreements.  See the NOTICE file
+## distributed with this work for additional information
+## regarding copyright ownership.  The ASF licenses this file
+## to you under the Apache License, Version 2.0 (the
+## "License"); you may not use this file except in compliance
+## with the License.  You may obtain a copy of the License at
+##
+##  http://www.apache.org/licenses/LICENSE-2.0
+##
+## Unless required by applicable law or agreed to in writing,
+## software distributed under the License is distributed on an
+## "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+## KIND, either express or implied.  See the License for the
+## specific language governing permissions and limitations
+## under the License.
+##
+
+##
+## $Rev: 438769 $ $Date: 2006-08-30 21:03:44 -0700 (Wed, 30 Aug 2006) $
+##
+
+### Character set mapping table loaded and used by the MimeUtility class.
+
+### java character sets to MIME character set map.  This must be the first table.
+
+8859_1		ISO-8859-1
+iso8859_1	ISO-8859-1
+ISO8859_1	ISO-8859-1
+
+8859_2		ISO-8859-2
+iso8859_2	ISO-8859-2
+ISO8859_2	ISO-8859-2
+
+8859_3		ISO-8859-3
+iso8859_3	ISO-8859-3
+ISO8859_3	ISO-8859-3
+
+8859_4		ISO-8859-4
+iso8859_4	ISO-8859-4
+ISO8859_4	ISO-8859-4
+
+8859_5		ISO-8859-5
+iso8859_5	ISO-8859-5
+ISO8859_5	ISO-8859-5
+
+8859_6		ISO-8859-6
+iso8859_6	ISO-8859-6
+ISO8859_6	ISO-8859-6
+
+8859_7		ISO-8859-7
+iso8859_7	ISO-8859-7
+ISO8859_7	ISO-8859-7
+
+8859_8		ISO-8859-8
+iso8859_8	ISO-8859-8
+ISO8859_8	ISO-8859-8
+
+8859_9		ISO-8859-9
+iso8859_9	ISO-8859-9
+ISO8859_9	ISO-8859-9
+
+SJIS		Shift_JIS
+MS932		Shift_JIS
+JIS		ISO-2022-JP
+ISO2022JP	ISO-2022-JP
+EUC_JP		euc-jp
+KOI8_R		koi8-r
+EUC_CN		euc-cn
+EUC_TW		euc-tw
+EUC_KR		euc-kr
+
+--Table terminator.  The "--" at the beginning and end are required --
+
+#### MIME to java character set map
+
+iso-2022-cn     ISO2022CN
+iso-2022-kr     ISO2022KR
+utf-8           UTF8
+utf8		UTF8
+ja_jp.iso2022-7 ISO2022JP
+ja_jp.eucjp     EUCJIS
+euc-kr          KSC5601
+euckr           KSC5601
+us-ascii        ISO-8859-1
+x-us-ascii      ISO-8859-1
--- geronimo/specs/trunk/geronimo-mail_2.1_spec/src/main/java/jakarta/mail/internet/MimeUtility.java (original)
+++ geronimo/specs/trunk/geronimo-mail_2.1_spec/src/main/java/jakarta/mail/internet/MimeUtility.java Tue Jun 21 12:36:31 2022
@@ -938,7 +938,7 @@ public class MimeUtility {
     /**
      * Load the default mapping tables used by the javaCharset()
      * and mimeCharset() methods.  By default, these tables are
      * loaded from the /META-INF/jakartamail.charset.map file.  If
      * something goes wrong loading that file, we configure things
      * with a default mapping table (which just happens to mimic
      * what's in the default mapping file).
@@ -950,7 +950,7 @@ public class MimeUtility {
 
         // normally, these come from a character map file contained in the jar file.
         try {
-            final InputStream map = MimeUtility.class.getResourceAsStream("/META-INF/jakartamail.charset.map");
+            final InputStream map = MimeUtility.class.getResourceAsStream("/META-INF/javamail.charset.map");
 
             if (map != null) {
                 // get a reader for this so we can load.
@@ -938,7 +938,7 @@ public class MimeUtility {
      * Load the default mapping tables used by the javaCharset()
      * and mimeCharset() methods.  By default, these tables are
-     * loaded from the /META-INF/jakartamail.charset.map file.  If
+     * loaded from the /META-INF/javamail.charset.map file.  If
      * something goes wrong loading that file, we configure things
      * with a default mapping table (which just happens to mimic

Added: geronimo/specs/trunk/geronimo-mail_2.1_spec/src/main/resources/META-INF/javamail.charset.map
URL: http://svn.apache.org/viewvc/geronimo/specs/trunk/geronimo-mail_2.1_spec/src/main/resources/META-INF/javamail.charset.map?rev=1902137&view=auto
==============================================================================